<?php

use BBC\Codes;

/**
 * No PGN, No playing Chess
 * @return bool
 */
function isPgnDisabled()
{
	global $modSettings;

	$disabled = !empty($modSettings['disabledBBC']) ? explode(',', $modSettings['disabledBBC']) : [];
	if (in_array('pgn', $disabled, true))
	{
		return true;
	}

	return false;
}

/**
 * Calls CSS file (if tag is not disabled in admin).
 * @return void
 */
function pgn_css()
{
	if (isPgnDisabled())
	{
		return;
	}

	loadCSSFile('pgn4web.css');
}

/**
 * Calls JS file (if tag is not disabled in admin).
 * @return void
 */
function pgn_js()
{
	if (isPgnDisabled())
	{
		return;
	}

	loadJavascriptFile('pgn4web.js', array('defer' => false));
	addInlineJavascript('pgn_render();', true);
}

/**
 * Codes hook for 1.1.x - integrate_additional_bbc
 * Called from ParseWrapper getCodes()
 *
 * @param array $codes
 * @return void
 */
function pgn_bbc(&$codes)
{
	$codes[] = array(
		Codes::ATTR_TAG => 'pgn',
		Codes::ATTR_TYPE => Codes::TYPE_PARSED_CONTENT,
		Codes::ATTR_BEFORE => '<textarea class="pgn4web_">',
		Codes::ATTR_AFTER => '</textarea><iframe class="pgn4web_board">Your web browser and/or your host does not support iframes as required to display the chessboard</iframe>',
		Codes::ATTR_DISABLED_CONTENT => '<div>$1</div>',
		Codes::ATTR_BLOCK_LEVEL => true,
		Codes::ATTR_AUTOLINK => true,
		Codes::ATTR_LENGTH => 3,
	);
}
